summaryrefslogtreecommitdiff
path: root/lisp/foldout.el
diff options
context:
space:
mode:
authorChong Yidong <cyd@gnu.org>2012-06-02 18:56:09 +0800
committerChong Yidong <cyd@gnu.org>2012-06-02 18:56:09 +0800
commit3726946669effb8c66c37fb5f9996178c9adfc80 (patch)
tree2e46f1c06178255d267bcf176b6579b6e06c5499 /lisp/foldout.el
parente7f322834d5535db4f3cae929aaa52766ca0ce24 (diff)
downloademacs-3726946669effb8c66c37fb5f9996178c9adfc80.tar.gz
Remove incorrect uses of "modeline".
* ansi-color.el (ansi-color-faces-vector): Change default faces. * cus-edit.el (mode-line): * dframe.el (dframe-mouse-hscroll): * emacs-lisp/re-builder.el: * emacs-lisp/easy-mmode.el (define-minor-mode): * frame.el (set-frame-name): * help.el (lookup-minor-mode-from-indicator): * net/rcirc.el (rcirc-activity-string, rcirc-short-buffer-name): * progmodes/cc-cmds.el (c-toggle-auto-newline) (c-toggle-hungry-state): * progmodes/antlr-mode.el (antlr-language-alist): * progmodes/idlw-shell.el (idlwave-shell-electric-stop-line-face): * progmodes/vhdl-mode.el (vhdl-mode): * progmodes/which-func.el (which-func, which-func-cleanup-function): * term/ns-win.el (ns-face-at-pos): * term/sup-mouse.el (sup-mouse-report): * textmodes/flyspell.el (flyspell-mode-line-string): * textmodes/ispell.el (ispell-highlight-face): * textmodes/reftex-global.el: * vc/vc-arch.el (vc-arch-mode-line-string): * vc/vc-cvs.el (vc-cvs-mode-line-string): * vc/vc-git.el (vc-git-mode-line-string): * vc/vc-hooks.el (vc-display-status) (vc-default-mode-line-string): * vc/vc-mtn.el (vc-mtn-mode-line-string): Doc fixes. * dired.el (dired-sort-set-mode-line): Rename from dired-sort-set-modeline. All callers changed. * foldout.el (foldout-mode-line-string): Rename from foldout-modeline-string. All callers changed. (foldout-update-mode-line): Rename from foldout-update-modeline. * strokes.el (strokes-lighter): Rename from strokes-modeline-string. * subr.el (redraw-modeline): Make into obsolete alias. * calendar/timeclock.el (timeclock-mode-line-display): Rename from timeclock-modeline-display. Make old name an alias. (timeclock-update-mode-line): Likewise. All callers changed. (timeclock-mode-line-display): No need to check before using add-hook. (timeclock-relative, timeclock-day-over-hook) (timeclock-use-elapsed, timeclock-mode-string) (timeclock-mode-line-display): Doc fix, "modeline" -> "mode line". * emulation/crisp.el (crisp-mode-mode-line-string): Rename from crisp-mode-modeline-string. * erc-track.el (erc-track, erc-track-faces-priority-list) (erc-track-faces-normal-list, erc-track-find-face) (erc-track-modified-channels): Fix modeline -> mode line in docs. * eshell/esh-mode.el (eshell-status-in-mode-line): Rename from eshell-status-in-modeline. * org-clock.el (org-clock-string-limit) (org-clock-modeline-total, org-clock-task-overrun-text) (org-clock-mode-line-entry): Doc fix, "modeline" -> "mode line". * play/solitaire.el (solitaire-build-mode-line): Rename from solitaire-build-modeline. All callers changed. * play/zone.el (zone-hiding-mode-line): Rename from zone-hiding-modeline. All callers changed. (zone): Remove unusued `modeline-hidden-level' property. * progmodes/xscheme.el (xscheme-mode-line-initialize): Rename from xscheme-modeline-initialize. All callers changed. * textmodes/sgml-mode.el (html-face-tag-alist) (html-tag-face-alist): Use mode-line face instead of obsolete alias modeline. Fixes: debbugs:10329
Diffstat (limited to 'lisp/foldout.el')
-rw-r--r--lisp/foldout.el40
1 files changed, 18 insertions, 22 deletions
diff --git a/lisp/foldout.el b/lisp/foldout.el
index 4081bfd2823..8d15416d557 100644
--- a/lisp/foldout.el
+++ b/lisp/foldout.el
@@ -39,7 +39,7 @@
;; look under one of the level-2 headings, position the cursor on it and do C-c
;; C-z again. This exposes the level-2 body and its level-3 child subheadings
;; and narrows the buffer again. You can keep on zooming in on successive
;; subheadings as much as you like. A string in the modeline tells you how
;; deep you've gone.
;;
;; When zooming in on a heading you might only want to see the child
@@ -194,7 +194,7 @@
;; shows only the subheadings.
;; 1.2 28-Jan-94
;; Fixed a dumb bug - didn't make `foldout-modeline-string' buffer-local :-(
;;
;; Changed `foldout-exit-fold' to use prefix arg to say how many folds to exit.
;; Negative arg means exit but don't hide text. Zero arg means exit all folds.
@@ -218,15 +218,15 @@
An end marker of nil means the fold ends after (point-max).")
(make-variable-buffer-local 'foldout-fold-list)
-(defvar foldout-modeline-string nil
- "Modeline string announcing that we are in an outline fold.")
-(make-variable-buffer-local 'foldout-modeline-string)
+(defvar foldout-mode-line-string nil
+ "Mode line string announcing that we are in an outline fold.")
+(make-variable-buffer-local 'foldout-mode-line-string)
;; put our minor mode string immediately following outline-minor-mode's
-(or (assq 'foldout-modeline-string minor-mode-alist)
+(or (assq 'foldout-mode-line-string minor-mode-alist)
(let ((outl-entry (memq (assq 'outline-minor-mode minor-mode-alist)
minor-mode-alist))
- (foldout-entry '((foldout-modeline-string foldout-modeline-string))))
+ (foldout-entry '((foldout-mode-line-string foldout-mode-line-string))))
;; something's wrong with outline if we can't find it
(if (null outl-entry)
@@ -296,8 +296,8 @@ optional arg EXPOSURE \(interactively with prefix arg\) changes this:-
(setq foldout-fold-list (cons (cons start-marker end-marker)
foldout-fold-list))
- ;; update the modeline
- (foldout-update-modeline)
+ ;; update the mode line
+ (foldout-update-mode-line)
)))
@@ -375,8 +375,7 @@ exited and text is left visible."
;; zap the markers so they don't slow down editing
(set-marker start-marker nil)
- (if end-marker (set-marker end-marker nil))
- )
+ (if end-marker (set-marker end-marker nil)))
;; narrow to the enclosing fold if there is one
(if foldout-fold-list
@@ -386,32 +385,29 @@ exited and text is left visible."
(narrow-to-region start-marker
(if end-marker
(1- (marker-position end-marker))
- (point-max)))
- ))
+ (point-max)))))
(recenter)
- ;; update the modeline
- (foldout-update-modeline)
- ))
+ ;; update the mode line
+ (foldout-update-mode-line)))
-(defun foldout-update-modeline ()
- "Set the modeline string to indicate our fold depth."
+(defun foldout-update-mode-line ()
+ "Set the mode line to indicate our fold depth."
(let ((depth (length foldout-fold-list)))
- (setq foldout-modeline-string
+ (setq foldout-mode-line-string
(cond
;; if we're not in a fold, keep quiet
((zerop depth)
nil)
;; in outline-minor-mode we're after "Outl:xx" in the modeline
(outline-minor-mode
(format ":%d" depth))
;; otherwise just announce the depth (I guess we're in outline-mode)
((= depth 1)
" Inside 1 fold")
(t
- (format " Inside %d folds" depth))
- ))))
+ (format " Inside %d folds" depth))))))
(defun foldout-mouse-zoom (event)
@@ -39,7 +39,7 @@
;; C-z again. This exposes the level-2 body and its level-3 child subheadings
;; and narrows the buffer again. You can keep on zooming in on successive
-;; subheadings as much as you like. A string in the modeline tells you how
+;; subheadings as much as you like. A string in the mode line tells you how
;; deep you've gone.
;;
@@ -194,7 +194,7 @@
;; shows only the subheadings.
;; 1.2 28-Jan-94
-;; Fixed a dumb bug - didn't make `foldout-modeline-string' buffer-local :-(
+;; Fixed a dumb bug - didn't make `foldout-mode-line-string' buffer-local :-(
;;
;; Changed `foldout-exit-fold' to use prefix arg to say how many folds to exit.
@@ -386,32 +385,29 @@ exited and text is left visible."
((zerop depth)
nil)
- ;; in outline-minor-mode we're after "Outl:xx" in the modeline
+ ;; in outline-minor-mode we're after "Outl:xx" in the mode line
(outline-minor-mode
(format ":%d" depth))